@@ -25,5 +25,8 @@ public class BackendDescriptor {
     public String userPath = null;
     public long maxVMemMB = -1;
     public int restartCount = 1;
-
+    public String blacklistFile = null;
+    public String whitelistFile = null;
+    public int urlLinkLimit = -1;
+    public String urlLinkProxy = null;
 }
