@@ -58,5 +58,19 @@ public enum JobPriority {
     LOW,
     MEDIUM,
     HIGH,
-    INSTANT
+    INSTANT;
+
+    /**
+     * @return the lowest of all possible priorities
+     */
+    static public JobPriority lowest() {
+        return JobPriority.LOW;
+    }
+
+    /**
+     * @return the highest of all possible priorities
+     */
+    static public JobPriority highest() {
+        return JobPriority.INSTANT;
+    }
 }
