@@ -123,6 +123,8 @@ public class Properties {
 
     static final public String PROP_CACHE_ONLY = "CacheOnly"; // Boolean
 
+    static final public String PROP_AUTOSCALE = "AutoScale"; // Boolean
+
     // -------------------------------------------------------------------------
 
     static final public String PROP_RESULT_CACHE_HASH = PROP_CACHE_HASH; // String
@@ -147,10 +149,6 @@ public class Properties {
 
     static final public String PROP_RESULT_PAGE_NUMBER = PROP_PAGE_NUMBER; // Integer
 
-    static final public String PROP_RESULT_PASSWORD_PROTECTED = "PasswordProtected"; // Boolean
-
-    static final public String PROP_RESULT_NO_DOCUMENT_CONTENT = "NoDocumentContent"; // Boolean
-
     static final public String PROP_RESULT_TEMP_INPUT_FILE = "TempInputFile"; // File
 
     static final public String PROP_RESULT_TEMP_INFO_FILENAME = PROP_INFO_FILENAME; // String
